@@ -27,6 +27,7 @@ class LibCreator(TemplateCreator):
 
         '"" TEMPLATE VERSIONS ""'
         self.LIB_JAVA_TEMPLATE_VERSION = load_qube_template_version('lib-java', self.AVAILABLE_TEMPLATES_PATH)
+        self.LIB_GROOVY_TEMPLATE_VERSION = load_qube_template_version('lib-groovy', self.AVAILABLE_TEMPLATES_PATH)
 
     def create_template(self, dot_qube: dict or None):
         """
@@ -34,8 +35,8 @@ class LibCreator(TemplateCreator):
         """
         self.lib_struct.language = qube_questionary_or_dot_qube(function='select',
                                                                 question='Choose the project\'s primary language',
-                                                                choices=['java'],
-                                                                default='java',
+                                                                choices=['java', 'groovy'],
+                                                                default='groovy',
                                                                 dot_qube=dot_qube,
                                                                 to_get_property='language')
 
@@ -45,6 +46,7 @@ class LibCreator(TemplateCreator):
         # switch case statement to prompt the user to fetch template specific configurations
         switcher = {
             'java': self.lib_java_options,
+            'groovy': self.lib_groovy_options
         }
         switcher.get(self.lib_struct.language)(dot_qube)
 
@@ -61,7 +63,8 @@ class LibCreator(TemplateCreator):
 
         # switch case statement to fetch the template version
         switcher_version = {
-            'java': self.LIB_JAVA_TEMPLATE_VERSION
+            'java': self.LIB_JAVA_TEMPLATE_VERSION,
+            'groovy': self.LIB_GROOVY_TEMPLATE_VERSION
         }
         self.lib_struct.template_version, self.lib_struct.template_handle = switcher_version.get(
             self.lib_struct.language), f'lib-{self.lib_struct.language.lower()}'
@@ -72,3 +75,7 @@ class LibCreator(TemplateCreator):
     def lib_java_options(self, dot_qube: dict or None) -> None:
         """ Prompts for lib-java specific options and saves them into the QubeTemplateStruct """
         pass
+
+    def lib_groovy_options(self, dot_qube: dict or None) -> None:
+        """ Prompts for lib-groovy specific options and saves them into the QubeTemplateStruct """
+        pass
